@@ -119,8 +119,8 @@ class Globals:
                 globalsEverything
             )
 
-            self.setting(f'{self.__class__.__name__}{c.DOT}filePath = {self.filePath}')
-            self.setting(f'__file__ = {__file__}')
+            self.setting(f'{self.__class__.__name__}{c.DOT}filePath: {self.filePath}')
+            self.setting(f'__file__: {__file__}')
 
             self.buildApplicationPath()
 
@@ -134,17 +134,17 @@ class Globals:
             self.apiNameList = self.getSetting(AttributeKey.GLOBALS_API_LIST)
 
             if self.printStatus :
-                print(f'''            {self.__class__.__name__} = {self}
-                {self.__class__.__name__}.staticPackage =   {self.staticPackage}
-                {self.__class__.__name__}.currentPath =     {self.currentPath}
-                {self.__class__.__name__}.localPath =       {self.localPath}
-                {self.__class__.__name__}.baseApiPath =     {self.baseApiPath}
-                {self.__class__.__name__}.apiPath =         {self.apiPath}
-                {self.__class__.__name__}.apisRoot =        {self.apisRoot}
-                {self.__class__.__name__}.apisPath =        {self.apisPath}
-                {self.__class__.__name__}.apiPackage =      {self.apiPackage}
-                {self.__class__.__name__}.apiName =         {self.apiName}
-                {self.__class__.__name__}.extension =       {self.extension}\n''')
+                print(f'''            {self.__class__.__name__}: {self}
+                {self.__class__.__name__}.staticPackage:    {self.staticPackage}
+                {self.__class__.__name__}.currentPath:      {self.currentPath}
+                {self.__class__.__name__}.localPath:        {self.localPath}
+                {self.__class__.__name__}.baseApiPath:      {self.baseApiPath}
+                {self.__class__.__name__}.apiPath:          {self.apiPath}
+                {self.__class__.__name__}.apisRoot:         {self.apisRoot}
+                {self.__class__.__name__}.apisPath:         {self.apisPath}
+                {self.__class__.__name__}.apiPackage:       {self.apiPackage}
+                {self.__class__.__name__}.apiName:          {self.apiName}
+                {self.__class__.__name__}.extension:        {self.extension}\n''')
 
                 self.printTree(self.settingTree,f'{self.__class__.__name__} settings tree')
 
@@ -185,14 +185,16 @@ class Globals:
             keyQuery = SettingHelper.querySetting(AttributeKey.KW_KEY,self.localConfiguration)
             keyValueQuery = {}
             for key,value in keyQuery.items() :
-                environmentInjection = SettingHelper.getSetting(key[:-4], self.localConfiguration)
-                if (
-                    ObjectHelper.isDictionary(environmentInjection) and
-                    AttributeKey.KW_KEY in environmentInjection and
-                    AttributeKey.KW_VALUE in environmentInjection and
-                    2 == len(environmentInjection)
-                ):
-                    EnvironmentHelper.update(environmentInjection[AttributeKey.KW_KEY], environmentInjection[AttributeKey.KW_VALUE])
+                KW_DOT_KEY = f'{c.DOT}{AttributeKey.KW_KEY}'
+                if key.endswith(KW_DOT_KEY) :
+                    environmentInjection = SettingHelper.getSetting(key[:-len(KW_DOT_KEY)], self.localConfiguration)
+                    if (
+                        ObjectHelper.isDictionary(environmentInjection) and
+                        AttributeKey.KW_KEY in environmentInjection and
+                        AttributeKey.KW_VALUE in environmentInjection and
+                        2 == len(environmentInjection)
+                    ):
+                        EnvironmentHelper.update(environmentInjection[AttributeKey.KW_KEY], environmentInjection[AttributeKey.KW_VALUE])
         log.loadSettings()
         self.settingsFileName = self.getSettingsFileName(settingsFileName)
         self.printRootPathStatus = printRootPathStatus
@@ -201,21 +203,21 @@ class Globals:
         self.ignoreResourceList = IGNORE_REOURCE_LIST
         if SettingHelper.getSetting('print-status', self.localConfiguration) :
             SettingHelper.printSettings(self.localConfiguration,"Local Configuration")
-        basicSettingsAsDictionary = {
-            'activeEnvironment' : self.activeEnvironment,
-            'settingsFileName' : self.settingsFileName,
-            'defaultSettingFileName' : self.defaultSettingFileName,
-            'successStatus' : self.successStatus,
-            'settingStatus' : self.settingStatus,
-            'debugStatus' : self.debugStatus,
-            'warningStatus' : self.warningStatus,
-            'failureStatus' : self.failureStatus,
-            'errorStatus' : self.errorStatus,
-            'logStatus' : self.logStatus,
-            'globalsEverything' : self.globalsEverything,
-            'printRootPathStatus' : self.printRootPathStatus
-        }
-        log.prettyPython(self.__class__, f'Basic settings', basicSettingsAsDictionary, logLevel=log.SETTING)
+            basicSettingsAsDictionary = {
+                'activeEnvironment' : self.activeEnvironment,
+                'settingsFileName' : self.settingsFileName,
+                'defaultSettingFileName' : self.defaultSettingFileName,
+                'successStatus' : self.successStatus,
+                'settingStatus' : self.settingStatus,
+                'debugStatus' : self.debugStatus,
+                'warningStatus' : self.warningStatus,
+                'failureStatus' : self.failureStatus,
+                'errorStatus' : self.errorStatus,
+                'logStatus' : self.logStatus,
+                'globalsEverything' : self.globalsEverything,
+                'printRootPathStatus' : self.printRootPathStatus
+            }
+            log.prettyPython(self.__class__, f'Basic settings', basicSettingsAsDictionary, logLevel=log.SETTING)
 
     def getSettingsFileName(self, settingsFileName) :
         self.defaultSettingFileName = settingsFileName
